@@ -41,8 +41,12 @@ void pdl_grow (pdl* a, int newsize) {
    if (ncurr == nbytes) 
       return;    /* Nothing to be done */
 
+/* We don't want to do this: if someone is resizing it 
+ * but wanting to preserve data.. */
+#ifdef FEOIJFOESIJFOJE
    if (ncurr>nbytes)  /* Nuke back to zero */
       sv_setpvn(foo,"",0);
+#endif
 
    if(nbytes > (1024*1024*1024)) {
    	die("Probably false alloc of over 1Gb piddle!");
