@@ -9,6 +9,17 @@ getopts('v');
 $dir = shift @ARGV;
 $outdb  = shift @ARGV;
 
+unless (defined $dir) {
+	require PDL;
+	($dir = $INC{'PDL.pm'}) =~ s/PDL\.pm$//i;
+	umask 0022;
+	print "DIR = $dir\n";
+}
+unless (defined $outdb) {
+	$outdb = "$dir/PDL/pdldoc.db";
+	print "DB  = $outdb\n";
+}
+
 $currdir = getcwd;
 
 chdir $dir or die "can't change to $dir";
